{% extends 'base.html' %}

{% block content %}
<h1>Description</h1>

<div class="row row-cols-2 text-center">
    <div class="col">
        previous: <a href="#">About</a>
    </div>
    <div class="col">
        next: <a href="#">Setup</a>
    </div>
</div>
{% endblock %}
