{% extends "base.html" %}

{% block content %}
{% if title %}
    <h3 class="mb-3">{{ title }}</h3>
{% endif %}
{%- if data -%}
    {% for key in ['device','action','pipeline'] %}
        {% if key in data %}
        <details>
            <summary class="mt-2">{{ key | capitalize }} Plugins</summary>
            {% for p in data[key] %}
            <div class="row row-cols-1 row-cols-md-2">
                <div class="col">
                    <a href="#" class="btn btn-sm btn-outline-primary w-100 mt-1">{{ p.name }}</a>
                </div>
            </div>
            {% endfor %}
        </details>
        {% endif %}
    {% endfor %}
{% else %}
0 plugins found?
{%- endif -%}

{% endblock %}
